/*
    Copyright 2006-2007 Kevin Ottens <ervin@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef SOLID_MANAGERBASE_P_H
#define SOLID_MANAGERBASE_P_H

#include <QtCore/QObject>
#include <QtCore/QString>

#include "config.h"
#include "solid/solid_export.h"

#ifdef ENABLE_TESTING
#  define MANAGERBASE_EXPORT SOLID_EXPORT
#else
#  define MANAGERBASE_EXPORT
#endif

namespace Solid
{
    class MANAGERBASE_EXPORT ManagerBasePrivate
    {
    public:
        ManagerBasePrivate();
        virtual ~ManagerBasePrivate();
        void loadBackends();

        QList<QObject*> managerBackends() const;

    private:
        QList<QObject*> m_backends;
    };
}

#endif
